.. mote documentation master file, created by
   sphinx-quickstart on Mon Oct 31 16:01:21 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Mote's documentation!
================================
In a countless number of industries, automation is becoming increasingly common. This is simply because automation of manufacturing processes produces consistent results, reduces human error, and ultimately saves a business money and increases the rate at which things are built.

In contrast with the process described above, user interfaces (particularly those on the web) are built by hand. Typically, these interfaces are interpretations of designs created in Photoshop or a similar tool.

If you are a fairly large brand, you might have numerous projects running in parallel, built by different teams of developers and designers, each of which has their own ideas about standards and how interfaces ought to be built. Is it any wonder at all, then, that these projects end up feeling disjointed, inconsistent and of varying degrees of quality?

Many brands suffer from this. Maybe even yours. Perhaps you only have one platform, and its own interface is riddled with inconsistency!

An interface which is consistent is one which creates a sense of trust in its users. They become familiar with its patterns, and learn how to interact with it as a matter of muscle memory.

"Don't make me think!" - this is what a successful interface accomplishes for its users. When faced with inconsistency, users may become frustrated or confused. This potentially damages your brand's image, and ultimately it may even damage your bottom line as a result.

In summation, at the heart of the issue lies the fact that your brand doesn't have full control over how its user interfaces are constructed and used. The answer, then, is standardisation and automation.

To that end, we have built Mote. Mote is a data-driven pattern library framework and continuous UI delivery service, which empowers brands and teams to automate and disseminate their UI across projects.

It allows non-engineers to collaborate on creating pattern libraries, and to serve these patterns over an API directly to a web or mobile site.

.. toctree::
   :maxdepth: 4

   architecture
   gettingstarted
   terminology
   directories
   patterns
   metadata
   api
   merging
   layering
   explorer
